@@ -28,7 +28,6 @@
 K_PLUGIN_FACTORY(USBFactory,
 		registerPlugin<USBViewer>();
 )
-K_EXPORT_PLUGIN(USBFactory("kcmusb"))
 
 USBViewer::USBViewer(QWidget *parent, const QVariantList &) :
 	KCModule(parent) {
@@ -67,7 +66,7 @@ USBViewer::USBViewer(QWidget *parent, const QVariantList &) :
 	connect(refreshTimer, &QTimer::timeout, this, &USBViewer::refresh);
 	connect(_devices, &QTreeWidget::currentItemChanged, this, &USBViewer::selectionChanged);
 
-	KAboutData *about = new KAboutData(i18n("kcmusb"), i18n("KDE USB Viewer"),
+	KAboutData *about = new KAboutData(i18n("kcmusb"), i18n("USB Devices"),
 			QString(), QString(), KAboutLicense::GPL,
 			i18n("(c) 2001 Matthias Hoelzer-Kluepfel"));
 
